@@ -17,6 +17,11 @@ describe 'designate::api' do
 
   shared_examples 'designate-api' do
     context 'with default parameters' do
+      it 'includes the dependent classes' do
+        is_expected.to contain_class('designate::deps')
+        is_expected.to contain_class('designate::policy')
+      end
+
       it 'installs designate-api package and service' do
         is_expected.to contain_service('designate-api').with(
           :name      => platform_params[:api_service_name],
@@ -40,7 +45,7 @@ describe 'designate::api' do
         is_expected.to contain_designate_config('service:api/workers').with_value(8)
         is_expected.to contain_designate_config('service:api/threads').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/enable_host_header').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_designate_config('service:api/max_header_line').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_designate_config('DEFAULT/max_header_line').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/default_limit_admin').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/max_limit_admin').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/default_limit_v2').with_value('<SERVICE DEFAULT>')
@@ -89,7 +94,7 @@ describe 'designate::api' do
         is_expected.to contain_designate_config('service:api/workers').with_value(params[:workers])
         is_expected.to contain_designate_config('service:api/threads').with_value(params[:threads])
         is_expected.to contain_designate_config('service:api/enable_host_header').with_value(params[:enable_host_header])
-        is_expected.to contain_designate_config('service:api/max_header_line').with_value(params[:max_header_line])
+        is_expected.to contain_designate_config('DEFAULT/max_header_line').with_value(params[:max_header_line])
         is_expected.to contain_designate_config('service:api/default_limit_admin').with_value(params[:default_limit_admin])
         is_expected.to contain_designate_config('service:api/max_limit_admin').with_value(params[:max_limit_admin])
         is_expected.to contain_designate_config('service:api/default_limit_v2').with_value(params[:default_limit_v2])
@@ -104,7 +109,7 @@ describe 'designate::api' do
       end
     end
 
-    context 'with enabled_extentions in list' do
+    context 'with enabled_extensions in list' do
       before do
         params.merge!({
           :enabled_extensions_v2    => ['ext1', 'ext2'],
