@@ -7,10 +7,9 @@ describe 'designate' do
 
   let :params do
     {
-      :package_ensure        => 'installed',
-      :purge_config          => false,
-      :neutron_endpoint_type => 'internalURL',
-      :root_helper           => 'sudo designate-rootwrap /etc/designate/rootwrap.conf'
+      :package_ensure => 'installed',
+      :purge_config   => false,
+      :root_helper    => 'sudo designate-rootwrap /etc/designate/rootwrap.conf'
     }
   end
 
@@ -34,16 +33,41 @@ describe 'designate' do
       it_configures 'a designate base installation'
     end
 
-    context 'without state_path' do
-      it { is_expected.to contain_designate_config('DEFAULT/state_path').with_value('/var/lib/designate') }
+    context 'without parameters' do
+      it 'configures the default values' do
+        is_expected.to contain_designate_config('DEFAULT/host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_designate_config('DEFAULT/state_path').with_value('/var/lib/designate')
+        is_expected.to contain_designate_config('DEFAULT/default_ttl').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_designate_config('DEFAULT/supported_record_type').with_value('<SERVICE DEFAULT>')
+      end
     end
 
-    context 'with state_path' do
+    context 'with parameters' do
       let :params do
-        { :state_path => '/var/tmp/designate' }
+        {
+          :host                  => 'current_hostname',
+          :state_path            => '/var/tmp/designate',
+          :default_ttl           => 3600,
+          :supported_record_type => 'A,AAAA'
+        }
       end
 
-      it { is_expected.to contain_designate_config('DEFAULT/state_path').with_value('/var/tmp/designate') }
+      it 'configures the given values' do
+        is_expected.to contain_designate_config('DEFAULT/host').with_value('current_hostname')
+        is_expected.to contain_designate_config('DEFAULT/state_path').with_value('/var/tmp/designate')
+        is_expected.to contain_designate_config('DEFAULT/default_ttl').with_value(3600)
+        is_expected.to contain_designate_config('DEFAULT/supported_record_type').with_value('A,AAAA')
+      end
+    end
+
+    context 'with supported_record_type (array)' do
+      let :params do
+        { :supported_record_type => ['A', 'AAAA'] }
+      end
+
+      it 'configures the given values' do
+        is_expected.to contain_designate_config('DEFAULT/supported_record_type').with_value('A,AAAA')
+      end
     end
   end
 
@@ -70,10 +94,6 @@ describe 'designate' do
       is_expected.to contain_designate_config('DEFAULT/root_helper').with_value( params[:root_helper] )
     end
 
-    it 'configures network endpoint type to use' do
-      is_expected.to contain_designate_config('network_api:neutron/endpoint_type').with_value( params[:neutron_endpoint_type] )
-    end
-
     it 'configures messaging' do
       is_expected.to contain_oslo__messaging__default('designate_config').with(
         :transport_url        => '<SERVICE DEFAULT>',
@@ -83,7 +103,7 @@ describe 'designate' do
       is_expected.to contain_oslo__messaging__notifications('designate_config').with(
         :driver        => 'messaging',
         :transport_url => '<SERVICE DEFAULT>',
-        :topics        => 'notifications'
+        :topics        => '<SERVICE DEFAULT>'
       )
       is_expected.to contain_oslo__messaging__rabbit('designate_config').with(
         :kombu_ssl_version       => '<SERVICE DEFAULT>',
@@ -92,7 +112,7 @@ describe 'designate' do
         :kombu_ssl_ca_certs      => '<SERVICE DEFAULT>',
         :kombu_reconnect_delay   => '<SERVICE DEFAULT>',
         :kombu_failover_strategy => '<SERVICE DEFAULT>',
-        :rabbit_use_ssl          => false,
+        :rabbit_use_ssl          => '<SERVICE DEFAULT>',
         :rabbit_ha_queues        => '<SERVICE DEFAULT>',
         :heartbeat_in_pthread    => '<SERVICE DEFAULT>',
         :amqp_durable_queues     => '<SERVICE DEFAULT>',
