@@ -17,12 +17,15 @@ describe 'designate::keystone::auth' do
         :configure_endpoint  => true,
         :service_name        => 'designate',
         :service_type        => 'dns',
-        :service_description => 'Openstack DNSaas Service',
+        :service_description => 'OpenStack DNSaas Service',
         :region              => 'RegionOne',
         :auth_name           => 'designate',
         :password            => 'designate_password',
         :email               => 'designate@localhost',
         :tenant              => 'services',
+        :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:9001',
         :internal_url        => 'http://127.0.0.1:9001',
         :admin_url           => 'http://127.0.0.1:9001',
@@ -35,10 +38,13 @@ describe 'designate::keystone::auth' do
           :auth_name           => 'alt_designate',
           :email               => 'alt_designate@alt_localhost',
           :tenant              => 'alt_service',
+          :roles               => ['admin', 'service'],
+          :system_scope        => 'alt_all',
+          :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
-          :service_description => 'Alternative Openstack DNSaas Service',
+          :service_description => 'Alternative OpenStack DNSaas Service',
           :service_name        => 'alt_service',
           :service_type        => 'alt_dns',
           :region              => 'RegionTwo',
@@ -53,12 +59,15 @@ describe 'designate::keystone::auth' do
         :configure_endpoint  => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_dns',
-        :service_description => 'Alternative Openstack DNSaas Service',
+        :service_description => 'Alternative OpenStack DNSaas Service',
         :region              => 'RegionTwo',
         :auth_name           => 'alt_designate',
         :password            => 'designate_password',
         :email               => 'alt_designate@alt_localhost',
         :tenant              => 'alt_service',
+        :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
