@@ -30,6 +30,7 @@ describe 'designate::logging' do
      :log_facility                   => 'LOG_FOO',
      :log_dir                        => '/var/log',
      :log_file                       => '/var/log/designate/designate.log',
+     :watch_log_file                 => true,
      :debug                          => true,
     }
   end
@@ -65,7 +66,8 @@ describe 'designate::logging' do
         :use_stderr          => '<SERVICE DEFAULT>',
         :syslog_log_facility => '<SERVICE DEFAULT>',
         :log_dir             => '/var/log/designate',
-        :log_file               => '<SERVICE DEFAULT>',
+        :log_file            => '<SERVICE DEFAULT>',
+        :watch_log_file      => '<SERVICE DEFAULT>',
         :debug               => '<SERVICE DEFAULT>',
       )
     end
@@ -81,6 +83,7 @@ describe 'designate::logging' do
         :syslog_log_facility => 'LOG_FOO',
         :log_dir             => '/var/log',
         :log_file            => '/var/log/designate/designate.log',
+        :watch_log_file      => true,
         :debug               => true,
       )
     end
